select_installer

Function select_installer 

pub(crate) fn select_installer(
    installers: &[CatalogInstaller],
    selection_context: SelectionContext,
) -> Result<CatalogInstaller, InstallerSelectionError>
Select the best installer for the current host.

The helper returns a structured error when the catalog package has no installers or when none of the installers are compatible with this host.